@@ -86,7 +86,15 @@ class MatchResult:
         return self._context.groups.items()
 
 
-class Pattern:
+class Capturable:
+    def __rshift__(self, other):
+        return Capture(self, name=other)
+
+    def __rmatmul__(self, other):
+        return Capture(self, name=other)
+
+
+class Pattern(Capturable):
     def match(self, value, *, ctx: MatchContext, strict: bool) -> MatchResult:
         raise NotImplementedError
 
@@ -164,7 +172,7 @@ class Capture(Pattern):
         return self._name
 
 
-class Some:
+class Some(Capturable):
     def __init__(self, pattern, /, *,
                  at_least: Optional[int] = None,
                  at_most: Optional[int] = None,
@@ -212,6 +220,8 @@ class Value(Pattern):
         self._value = value
 
     def match(self, value, *, ctx: MatchContext, strict: bool) -> MatchResult:
+        if self._value is Ellipsis:
+            return ctx.matches()
         if strict:
             if type(self._value) != type(value):
                 return ctx.no_match()
@@ -354,26 +364,4 @@ def _match_list(value, pattern, *, ctx: MatchContext, strict: bool) -> MatchResu
         return ctx.match_if(not item_queued)
 
 
-class AttributesAdapter:
-    def __init__(self, base):
-        self._base = base
-
-    def __bool__(self):
-        return bool(self._base)
-
-    def __getattr__(self, item):
-        try:
-            return self._base[item]
-        except KeyError as err:
-            raise AttributeError(*err.args)
-
-
-def match(value, pattern, *, multimatch=True, strict=False, argresult=False) -> MatchResult:
-    ctx = MatchContext(
-        multimatch=multimatch,
-        strict=strict,
-    )
-    result = ctx.match(value, pattern, strict=strict)
-    if argresult:
-        result = AttributesAdapter(result)
-    return result
+_ = Value(...)
